@@ -3,7 +3,7 @@
 
 #include <QWidget>
 
-#include "dtkwidget_global.h"
+#include <dtkwidget_global.h>
 #include "examplewindowinterface.h"
 #include "pagewindowinterface.h"
 
