@@ -23,12 +23,17 @@
 #include <QApplication>
 #include <QMouseEvent>
 #include <QProcess>
+#include <QStandardPaths>
 
 #include <DWindowManagerHelper>
 #include <DObjectPrivate>
 #include <DPlatformTheme>
 #include <QScreen>
+#include <QWindow>
+#include <qpa/qplatformwindow.h>
 
+#include "dpalettehelper.h"
+#include "dstyleoption.h"
 #include "dwindowclosebutton.h"
 #include "dwindowmaxbutton.h"
 #include "dwindowminbutton.h"
@@ -39,6 +44,7 @@
 #include "daboutdialog.h"
 #include "dapplication.h"
 #include "private/dapplication_p.h"
+#include "private/dsplitscreen_p.h"
 #include "dmainwindow.h"
 #include "DHorizontalLine"
 #include "dimagebutton.h"
@@ -48,6 +54,9 @@
 
 DWIDGET_BEGIN_NAMESPACE
 
+#define CHANGESPLITWINDOW_VAR "_d_splitWindowOnScreen"
+#define GETSUPPORTSPLITWINDOW_VAR "_d_supportForSplittingWindow"
+
 const int DefaultTitlebarHeight = 50;
 const int DefaultIconHeight = 32;
 const int DefaultIconWidth = 32;
@@ -80,6 +89,7 @@ private:
 #ifndef QT_NO_MENU
     void _q_addDefaultMenuItems();
     void _q_helpActionTriggered();
+    void _q_feedbackActionTriggerd();
     void _q_aboutActionTriggered();
     void _q_quitActionTriggered();
     void _q_switchThemeActionTriggered(QAction*action);
@@ -87,6 +97,11 @@ private:
 
     void setIconVisible(bool visible);
     void updateTabOrder();
+    void showSplitScreenWidget();
+    void hideSplitScreenWidget();
+    /*SplitLeft: 1; SplitRight: 2; SplitFullScreen: 15*/
+    void changeWindowSplitedState(quint32 type);
+    bool supportSplitScreenByWM();
 
     QHBoxLayout         *mainLayout;
     QWidget             *leftArea;
@@ -109,10 +124,12 @@ private:
     DHorizontalLine     *separator;
 
     DBlurEffectWidget   *blurWidget = nullptr;
+    QPointer<DSplitScreenWidget>  splitWidget = nullptr;
 
 #ifndef QT_NO_MENU
     QMenu               *menu             = Q_NULLPTR;
     QAction             *helpAction       = Q_NULLPTR;
+    QAction             *feedbackAction   = Q_NULLPTR;
     QAction             *aboutAction      = Q_NULLPTR;
     QAction             *quitAction       = Q_NULLPTR;
     bool                canSwitchTheme    = true;
@@ -130,10 +147,212 @@ private:
     bool                embedMode       = false;
     bool                autoHideOnFullscreen = false;
     bool                fullScreenButtonVisible = true;
+    bool                splitScreenWidgetEnable = true;
 
     Q_DECLARE_PUBLIC(DTitlebar)
 };
 
+DSplitScreenButton::DSplitScreenButton(DStyle::StandardPixmap sp, QWidget *parent)
+    : DIconButton(sp, parent)
+{
+    this->setIconSize(QSize(36, 36));
+
+    auto dpal = DPaletteHelper::instance()->palette(this);
+    dpal.setColor(DPalette::FrameBorder, Qt::transparent);
+    DPaletteHelper::instance()->setPalette(this, dpal);
+}
+
+void DSplitScreenButton::initStyleOption(DStyleOptionButton *option) const
+{
+    DIconButton::initStyleOption(option);
+
+    bool hover = (option->state & QStyle::State_MouseOver);
+    bool selected = (option->state & QStyle::State_Sunken);
+
+    if (hover && !selected) {
+        // 调整背景色和图标调色板
+        auto pal = option->palette;
+        auto dpal = DPaletteHelper::instance()->palette(this);
+        QColor backgroundBrush = dpal.itemBackground().color();
+        QColor iconForeColor = Qt::white;
+        if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType) {
+            backgroundBrush = DStyle::adjustColor(backgroundBrush, 0, 0, 0, 0, 0, 0, 3);
+            iconForeColor = dpal.textTiele().color();
+        }
+
+        pal.setBrush(QPalette::Light, backgroundBrush);
+        pal.setBrush(QPalette::Dark, backgroundBrush);
+        pal.setBrush(QPalette::ButtonText, iconForeColor);
+
+        option->palette = pal;
+    } else if (!hover && !selected) {
+        option->features |= (QStyleOptionButton::Flat | QStyleOptionButton::ButtonFeature(DStyleOptionButton::TitleBarButton));
+    }
+}
+
+DSplitScreenWidget::DSplitScreenWidget(FloatMode mode, QWidget *parent)
+    : DArrowRectangle(ArrowTop, mode, parent)
+    , floatMode(mode)
+{
+    this->init();
+}
+
+void DSplitScreenWidget::hide()
+{
+    if (!hideTimer.isActive())
+        hideTimer.start(300, this);
+}
+
+void DSplitScreenWidget::hideImmediately()
+{
+    close();
+}
+
+void DSplitScreenWidget::updateMaximizeButtonIcon(bool isMaximized)
+{
+    if (isMaximized) {
+        this->maximizeButton->setIcon(DStyle::SP_Title_SS_ShowNormalButton);
+        this->maximizeButton->setToolTip(qApp->translate("DSplitScreenWidget", "Unmaximize"));
+    } else {
+        this->maximizeButton->setIcon(DStyle::SP_Title_SS_ShowMaximizeButton);
+        this->maximizeButton->setToolTip(qApp->translate("DSplitScreenWidget", "Maximize"));
+    }
+}
+
+void DSplitScreenWidget::setButtonsEnable(bool enable)
+{
+    this->maximizeButton->setEnabled(enable);
+    this->leftSplitButton->setEnabled(enable);
+    this->rightSplitButton->setEnabled(enable);
+}
+
+void DSplitScreenWidget::onThemeTypeChanged(DGuiApplicationHelper::ColorType ct)
+{
+    if (ct == DGuiApplicationHelper::DarkType) {
+        this->setBackgroundColor(QColor(25, 25, 25, qRound(0.8 * 255)));
+    } else {
+        this->setBackgroundColor(this->palette().window().color());
+    }
+}
+
+void DSplitScreenWidget::init()
+{
+    this->setAttribute(Qt::WA_DeleteOnClose);
+    this->setWindowFlag(Qt::ToolTip);
+    this->setMargin(10);
+    this->setShadowXOffset(0);
+    this->setShadowYOffset(6);
+    this->setShadowBlurRadius(20);
+    this->setRadius(18);
+    this->setArrowWidth(50);
+    this->setArrowHeight(30);
+    this->setRadiusArrowStyleEnable(true);
+    this->setBorderColor(QColor(0, 0, 0, qRound(0.05 * 255)));
+
+    contentWidget = new QWidget(this);
+    QHBoxLayout *contentLayout = new QHBoxLayout(contentWidget);
+
+    this->leftSplitButton = new DSplitScreenButton(DStyle::SP_Title_SS_LeftButton, this);
+    this->rightSplitButton = new DSplitScreenButton(DStyle::SP_Title_SS_RightButton, this);
+    this->maximizeButton = new DSplitScreenButton(DStyle::SP_Title_SS_ShowNormalButton, this);
+    this->leftSplitButton->setToolTip(qApp->translate("DSplitScreenWidget", "Tile window to left of screen"));
+    this->rightSplitButton->setToolTip(qApp->translate("DSplitScreenWidget", "Tile window to right of screen"));
+
+    contentLayout->setMargin(0);
+    contentLayout->setSpacing(10);
+    contentLayout->addWidget(this->leftSplitButton);
+    contentLayout->addWidget(this->rightSplitButton);
+    contentLayout->addWidget(this->maximizeButton);
+
+    this->setContent(contentWidget);
+    onThemeTypeChanged(DGuiApplicationHelper::instance()->themeType());
+    qApp->installEventFilter(this);
+
+    disabledByScreenGeometryAndWindowSize({leftSplitButton, rightSplitButton});
+
+    QObject::connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &DSplitScreenWidget::onThemeTypeChanged);
+    QObject::connect(this->leftSplitButton, &DSplitScreenButton::clicked, this, &DSplitScreenWidget::leftSplitScreenButtonClicked);
+    QObject::connect(this->rightSplitButton, &DSplitScreenButton::clicked, this, &DSplitScreenWidget::rightSplitScreenButtonClicked);
+    QObject::connect(this->maximizeButton, &DSplitScreenButton::clicked, this, &DSplitScreenWidget::maximizeButtonClicked);
+}
+
+void DSplitScreenWidget::disabledByScreenGeometryAndWindowSize(QWidgetList wList)
+{
+    QDesktopWidget *desktop = qApp->desktop();
+    QWidget *window = this->window();
+
+    if (Q_LIKELY(desktop) && Q_LIKELY(window)) {
+        QRect screenRect = desktop->screenGeometry(window);
+
+        // 窗口尺寸大于屏幕分辨率时 禁用控件
+        if (screenRect.width() < window->minimumWidth() || screenRect.height() < window->minimumHeight())
+            for (QWidget *w : wList)
+                w->setDisabled(true);
+    }
+}
+
+bool DSplitScreenWidget::eventFilter(QObject *o, QEvent *e)
+{
+    switch (e->type()) {
+    case QEvent::Enter:
+        if (o == this)
+            hideTimer.stop();
+        break;
+
+    case QEvent::Leave:
+        if (o == this)
+            hide();
+        break;
+
+    case QEvent::Close:
+        if (!o->objectName().compare(QLatin1String("qtooltip_label")))
+            break;
+
+        Q_FALLTHROUGH();
+    case QEvent::WindowActivate:
+    case QEvent::WindowDeactivate:
+    case QEvent::FocusIn:
+    case QEvent::FocusOut:
+    case QEvent::MouseButtonRelease:
+    case QEvent::MouseButtonDblClick:
+    case QEvent::Wheel:
+        hideImmediately();
+        break;
+    default:
+        break;
+    }
+
+    return false;
+}
+
+void DSplitScreenWidget::showEvent(QShowEvent *e)
+{
+    this->setContent(contentWidget);
+    DArrowRectangle::showEvent(e);
+
+    QRect rect = this->rect();
+    qreal delta = this->shadowBlurRadius();
+    int arrowSpacing = (DArrowRectangle::FloatWidget == floatMode) ? this->arrowWidth() / 2 : this->arrowWidth();
+
+    if (DApplication::isDXcbPlatform())
+        rect = rect.marginsRemoved(QMarginsF(delta, (DArrowRectangle::FloatWidget == floatMode) ? 0 : delta,
+                                             delta, delta - this->margin()).toMargins());
+    else
+        rect = rect.marginsRemoved(QMarginsF(delta, 0, delta, (DArrowRectangle::FloatWidget == floatMode)
+                                             ? delta - this->margin() : delta * 2).toMargins());
+
+
+    this->setArrowX(rect.width() / 2 + arrowSpacing);
+}
+
+void DSplitScreenWidget::timerEvent(QTimerEvent *e)
+{
+    if (e->timerId() == hideTimer.timerId()) {
+        hideTimer.stop();
+        hideImmediately();
+    }
+}
+
 DTitlebarPrivate::DTitlebarPrivate(DTitlebar *qq)
     : DObjectPrivate(qq)
     , quitFullButton(nullptr)
@@ -182,6 +401,7 @@ void DTitlebarPrivate::init()
     maxButton->setObjectName("DTitlebarDWindowMaxButton");
     maxButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
     maxButton->setAccessibleName("DTitlebarDWindowMaxButton");
+    maxButton->setAttribute(Qt::WA_AlwaysShowToolTips);
     closeButton->setObjectName("DTitlebarDWindowCloseButton");
     closeButton->setAccessibleName("DTitlebarDWindowCloseButton");
     closeButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
@@ -286,7 +506,7 @@ void DTitlebarPrivate::init()
     q->setFocusPolicy(Qt::StrongFocus);
 
     // fix wayland 下显示了两个应用图标，系统标题栏 和 dtk标题栏 均显示应用图标
-    q->setEmbedMode(!DApplication::isDXcbPlatform());
+    q->setEmbedMode(!(DApplication::isDXcbPlatform()|| (qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool())));
 }
 
 QWidget *DTitlebarPrivate::targetWindow()
@@ -379,9 +599,14 @@ void DTitlebarPrivate::updateButtonsState(Qt::WindowFlags type)
 
     bool allowResize = true;
 
-    if (q->window() && q->window()->windowHandle()) {
-        auto functions_hints = DWindowManagerHelper::getMotifFunctions(q->window()->windowHandle());
-        allowResize = functions_hints.testFlag(DWindowManagerHelper::FUNC_RESIZE);
+    if (QWidget * window = q->window()) {
+        if (window->windowHandle()) {
+            auto functions_hints = DWindowManagerHelper::getMotifFunctions(window->windowHandle());
+            allowResize = functions_hints.testFlag(DWindowManagerHelper::FUNC_RESIZE);
+        }
+
+        if (allowResize && Q_LIKELY(q->testAttribute(Qt::WA_WState_Created)) && Q_LIKELY(q->testAttribute(Qt::WA_Resized)))
+            allowResize = (window->maximumSize() != window->minimumSize());
     }
 
     bool showMax = (type.testFlag(Qt::WindowMaximizeButtonHint) || forceShow) && !forceHide && allowResize;
@@ -441,7 +666,7 @@ void DTitlebarPrivate::updateCenterArea()
 
 void DTitlebarPrivate::handleParentWindowStateChange()
 {
-    maxButton->setMaximized(targetWindow()->windowState() == Qt::WindowMaximized);
+    maxButton->setMaximized(targetWindow()->windowState().testFlag(Qt::WindowMaximized));
     updateFullscreen();
     updateButtonsState(targetWindow()->windowFlags());
 }
@@ -476,6 +701,9 @@ void DTitlebarPrivate::_q_toggleWindowState()
                && (maxButton->isVisible())) {
         parentWindow->showMaximized();
     }
+
+    if (splitWidget)
+        splitWidget->updateMaximizeButtonIcon(parentWindow->isMaximized());
 }
 
 void DTitlebarPrivate::_q_showMinimized()
@@ -516,7 +744,11 @@ void DTitlebarPrivate::_q_onTopWindowMotifHintsChanged(quint32 winId)
     minButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_MINIMIZE));
     maxButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_MAXIMIZE)
                           && functions_hints.testFlag(DWindowManagerHelper::FUNC_RESIZE));
-    closeButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_CLOSE));
+    if (!qgetenv("WAYLAND_DISPLAY").isEmpty() && disableFlags.testFlag(Qt::WindowCloseButtonHint)) {
+        closeButton->setEnabled(false);
+    } else {
+        closeButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_CLOSE));
+    }
     // sync button state
 #if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     disableFlags.setFlag(Qt::WindowMinimizeButtonHint, !minButton->isEnabled());
@@ -536,7 +768,7 @@ void DTitlebarPrivate::_q_addDefaultMenuItems()
     D_Q(DTitlebar);
 
     // add switch theme sub menu
-    if (!switchThemeMenu) {
+    if (!switchThemeMenu && DGuiApplicationHelper::testAttribute(DGuiApplicationHelper::Attribute::IsDeepinPlatformTheme)) {
         bool disableDtkSwitchThemeMenu = qEnvironmentVariableIsSet("KLU_DISABLE_MENU_THEME");
         if (!disableDtkSwitchThemeMenu) {
             switchThemeMenu = new QMenu(qApp->translate("TitleBarMenu", "Theme"), menu);
@@ -574,6 +806,13 @@ void DTitlebarPrivate::_q_addDefaultMenuItems()
         helpAction->setVisible(false);
     }
 
+    // add feedback menu item for deepin or uos application
+    if (!feedbackAction && qApp->organizationName() == "deepin" && !QStandardPaths::findExecutable("deepin-feedback").isEmpty()) {
+        feedbackAction = new QAction(qApp->translate("TitleBarMenu", "Feedback"), menu);
+        QObject::connect(feedbackAction, SIGNAL(triggered(bool)), q, SLOT(_q_feedbackActionTriggerd()));
+        menu->addAction(feedbackAction);
+    }
+
     // add about menu item.
     if (!aboutAction) {
         aboutAction = new QAction(qApp->translate("TitleBarMenu", "About"), menu);
@@ -599,6 +838,10 @@ void DTitlebarPrivate::_q_helpActionTriggered()
     }
 }
 
+void DTitlebarPrivate::_q_feedbackActionTriggerd() {
+    QProcess::startDetached("deepin-feedback", { qApp->applicationName() });
+}
+
 void DTitlebarPrivate::_q_aboutActionTriggered()
 {
     DApplication *dapp = qobject_cast<DApplication *>(qApp);
@@ -678,32 +921,135 @@ void DTitlebarPrivate::updateTabOrder()
     }
 }
 
+void DTitlebarPrivate::showSplitScreenWidget()
+{
+    D_Q(DTitlebar);
+
+    if (!splitScreenWidgetEnable)
+        return;
+
+    if (disableFlags.testFlag(Qt::WindowMaximizeButtonHint))
+        return;
+
+    // 应产品要求 2D 模式下不对窗口分屏做任何显示
+    if (auto wmHelper = DWindowManagerHelper::instance()) {
+        if (!wmHelper->hasComposite())
+            return;
+    }
+
+    // 窗管不支持分屏时，不显示分屏菜单
+    if (!Q_LIKELY(supportSplitScreenByWM()))
+        return;
+
+    if (!splitWidget) {
+        splitWidget = new DSplitScreenWidget(DSplitScreenWidget::FloatWidget, q->window());
+
+        QObject::connect(splitWidget, &DSplitScreenWidget::maximizeButtonClicked, q,
+                         std::bind(&DTitlebarPrivate::changeWindowSplitedState, this, DSplitScreenWidget::SplitFullScreen));
+        QObject::connect(splitWidget, &DSplitScreenWidget::leftSplitScreenButtonClicked, q,
+                         std::bind(&DTitlebarPrivate::changeWindowSplitedState, this, DSplitScreenWidget::SplitLeftHalf));
+        QObject::connect(splitWidget, &DSplitScreenWidget::rightSplitScreenButtonClicked, q,
+                         std::bind(&DTitlebarPrivate::changeWindowSplitedState, this, DSplitScreenWidget::SplitRightHalf));
+    }
+
+    if (splitWidget->isVisible())
+        return;
+
+    if (auto window = targetWindow())
+        splitWidget->updateMaximizeButtonIcon(window->isMaximized());
+
+    auto centerPos = maxButton->mapToGlobal(maxButton->rect().center());
+    auto bottomPos = maxButton->mapToGlobal(maxButton->rect().bottomLeft());
+
+    QRect rect;
+    if (QScreen *screen = QGuiApplication::screenAt(QCursor::pos())) {
+        rect = screen->geometry();
+    } else {
+        rect = QGuiApplication::primaryScreen()->geometry();
+    }
+
+    if (bottomPos.y() + splitWidget->height() > rect.height()) {
+        splitWidget->setArrowDirection(DArrowRectangle::ArrowBottom);
+        splitWidget->show(centerPos.x() - splitWidget->arrowWidth() / 2, bottomPos.y() - maxButton->rect().height());
+    } else {
+        splitWidget->setArrowDirection(DArrowRectangle::ArrowTop);
+        splitWidget->show(centerPos.x() - splitWidget->arrowWidth() / 2, bottomPos.y());
+    }
+}
+
+void DTitlebarPrivate::hideSplitScreenWidget()
+{
+    if (!splitWidget)
+        return;
+
+    if (splitWidget->isHidden())
+        return;
+
+    splitWidget->hide();
+}
+
+void DTitlebarPrivate::changeWindowSplitedState(quint32 type)
+{
+    //### 目前接口尚不公开在 dtkgui 中，等待获取后续接口稳定再做移植
+    D_Q(DTitlebar);
+    QFunctionPointer splitWindowOnScreen = Q_NULLPTR;
+
+    splitWindowOnScreen = qApp->platformFunction(CHANGESPLITWINDOW_VAR);
+
+    const QWindow *windowHandle = nullptr;
+    const QWidget *window = q->window();
+
+    if (window)
+        windowHandle  = window->windowHandle();
+
+    if (splitWindowOnScreen && windowHandle && windowHandle->handle())
+        reinterpret_cast<void(*)(quint32, quint32)>(splitWindowOnScreen)(windowHandle->handle()->winId(), type);
+}
+
+bool DTitlebarPrivate::supportSplitScreenByWM()
+{
+    //### 目前接口尚不公开在 dtkgui 中，等待获取后续接口稳定再做移植
+    D_Q(DTitlebar);
+    QFunctionPointer getSupportSplitWindow = Q_NULLPTR;
+    bool supported = false;
+
+    getSupportSplitWindow = qApp->platformFunction(GETSUPPORTSPLITWINDOW_VAR);
+
+    const QWindow *windowHandle = nullptr;
+    const QWidget *window = q->window();
+
+    if (window)
+        windowHandle  = window->windowHandle();
+
+    if (getSupportSplitWindow && windowHandle && windowHandle->handle())
+        supported = reinterpret_cast<bool(*)(quint32)>(getSupportSplitWindow)(windowHandle->handle()->winId());
+
+    return supported;
+}
+
 #endif
 
 /*!
- * \~english \class DTitlebar
- * \brief The DTitlebar class is an universal title bar on the top of windows.
- * \param parent is the parent widget to be attached on.
- *
- * Usually you don't need to construct a DTitlebar instance by your self, you
- * can get an DTitlebar instance by DMainWindow::titlebar .
- */
-/*!
- * \~chinese \class DTitlebar
- * \brief Dtitlebar是Dtk程序通用的标题栏组件，用于实现标题栏的高度定制化。
- * \param 父组件，一般为标题栏所在的窗口
- *
- * 一般情况下，请使用Dtk::Widget::DMainWindow::titlebar()来获取已经自动初始化的标题栏，
- * 不要自己来创建这个标题栏。
+  \class Dtk::Widget::DTitlebar
+  \inmodule dtkwidget
+
+  \brief The DTitlebar class is an universal title bar on the top of windows.
+  \brief Dtitlebar是Dtk程序通用的标题栏组件，用于实现标题栏的高度定制化.
+
+  \a parent is the parent widget to be attached on.
+  \a 父组件，一般为标题栏所在的窗口
+  
+  Usually you don't need to construct a DTitlebar instance by your self, you
+  can get an DTitlebar instance by DMainWindow::titlebar .
+  一般情况下，请使用Dtk::Widget::DMainWindow::titlebar()来获取已经自动初始化的标题栏，
+  不要自己来创建这个标题栏。
  */
 
+/*!
+  \brief This function provides to create an default widget with icon/title/ and buttons
+  \brief 创建一个DTitlebar对象，包含默认的窗口按钮.
 
-/*!
- *  \~english @brief DTitlebar::DTitlebar create an default widget with icon/title/and buttons
- * @param parent
- */
-/*!
- *  \~chinese @brief 创建一个DTitlebar对象，包含默认的窗口按钮。
+  \a parent 父控件指针
  */
 DTitlebar::DTitlebar(QWidget *parent) :
     QFrame(parent),
@@ -724,13 +1070,12 @@ DTitlebar::DTitlebar(QWidget *parent) :
 
 #ifndef QT_NO_MENU
 /*!
- * \~english @brief DTitlebar::menu holds the QMenu object attached to this title bar.
- * @return the QMenu object it holds, returns null if there's no one set.
- */
-/*!
- * \~chinese @brief 获取和标题栏关联的应用查询菜单。
- * @return 如该标题栏没有设置菜单，这里会返回空，但是如该使用 Dtk::Widget::DApplication ,
- * 那么这里一般会自动创建一个程序菜单。
+  \brief DTitlebar::menu holds the QMenu object attached to this title bar.
+  \brief 获取和标题栏关联的应用查询菜单.
+
+  \return 如该标题栏没有设置菜单，这里会返回空，但是如该使用 Dtk::Widget::DApplication ,
+  那么这里一般会自动创建一个程序菜单。
+  \return the QMenu object it holds, returns null if there's no one set.
  */
 QMenu *DTitlebar::menu() const
 {
@@ -740,12 +1085,11 @@ QMenu *DTitlebar::menu() const
 }
 
 /*!
- * \~english @brief DTitlebar::setMenu attaches a QMenu object to the title bar.
- * @param menu is the target menu.
- */
-/*!
- * \~chinese @brief 设置自定义的程序菜单
- * @param 需要被设置的菜单
+  \brief DTitlebar::setMenu attaches a QMenu object to the title bar.
+  \brief 设置自定义的程序菜单.
+
+  \a menu is the target menu.
+  \a menu 需要被设置的菜单
  */
 void DTitlebar::setMenu(QMenu *menu)
 {
@@ -771,19 +1115,16 @@ void DTitlebar::setMenu(QMenu *menu)
 #endif
 
 /*!
- * \~english @brief DTitlebar::customWidget
- * @return the customized widget used in this title bar.
- *
- * One can set customized widget to show some extra widgets on the title bar.
- * \see Dtk::Widget::DTitlebar::setCustomWidget()
- */
-/*!
- * \~chinese @brief 标题栏绑定的自定义控件
- * @return 自定义控件
- *
- * 可以通过自定义控件来在标题栏上显示复杂的组合控件
- *
- * \see Dtk::Widget::DTitlebar::setCustomWidget()
+  \brief DTitlebar::customWidget
+  \brief 标题栏绑定的自定义控件
+  
+  \return the customized widget used in this title bar.
+  \return 自定义控件
+  
+  One can set customized widget to show some extra widgets on the title bar.
+  可以通过自定义控件来在标题栏上显示复杂的组合控件
+  
+  \sa Dtk::Widget::DTitlebar::setCustomWidget()
  */
 QWidget *DTitlebar::customWidget() const
 {
@@ -794,12 +1135,9 @@ QWidget *DTitlebar::customWidget() const
 
 #ifndef QT_NO_MENU
 /*!
- * \~english \brief DTitlebar::showMenu pop the menu of application on titlebar.
+  \brief DTitlebar::showMenu pop the menu of application on titlebar.
+  \brief 弹出应用程序菜单
  */
-/*!
- * \~chineses \brief 弹出应用程序菜单
- */
-
 void DTitlebar::showMenu()
 {
     D_D(DTitlebar);
@@ -839,6 +1177,13 @@ void DTitlebar::showMenu()
 
 void DTitlebar::showEvent(QShowEvent *event)
 {
+    if (qobject_cast<QDialog *>(topLevelWidget())) {
+        // QDialog::setvisible will send QFocusEvent (QEvent::FocusIn, Qt::TabFocusReason);
+        // that will cause DTitlebar focus to next widget(see DTitlebar::event)
+        if (topLevelWidget()->focusWidget() == this)
+            clearFocus();
+    }
+
     //fix the width issue and process menu
     D_D(DTitlebar);
     d->separatorTop->setFixedWidth(width());
@@ -925,6 +1270,20 @@ bool DTitlebar::eventFilter(QObject *obj, QEvent *event)
         default:
             break;
         }
+    } else if (obj == d->maxButton) {
+        switch (event->type()) {
+        case QEvent::ToolTip: {
+            d->showSplitScreenWidget();
+            break;
+        }
+        case QEvent::Leave: {
+            d->hideSplitScreenWidget();
+            break;
+        }
+        default:
+            break;
+
+        }
     }
     return QWidget::eventFilter(obj, event);
 }
@@ -937,6 +1296,15 @@ bool DTitlebar::event(QEvent *e)
         d->updateCenterArea();
     }
 
+    if (e->type() == QEvent::FocusIn) {
+        QFocusEvent *fe = static_cast<QFocusEvent*>(e);
+        if (fe->reason() == Qt::TabFocusReason || fe->reason() == Qt::BacktabFocusReason) {
+            e->accept();
+            // 还需要 Tab 切换焦点时不不会出现再自己身上减少一次按 Tab 键 fix bug-65703
+            fe->reason() == Qt::TabFocusReason ? focusNextChild() : focusPreviousChild();
+        }
+    }
+
     return QFrame::event(e);
 }
 
@@ -957,16 +1325,16 @@ void DTitlebar::resizeEvent(QResizeEvent *event)
 }
 
 /*!
- * \~english @brief DTitlebar::setCustomWidget is an overloaded function.
- * @param w is the widget to be used as the customize widget shown in the title
- * bar.
- * @param fixCenterPos indicates whether it should automatically move the
- * customize widget to the horizontal center of the title bar or not.
- */
-/*!
- * \~chinese @brief 设置标题栏上的自定义控件
- * @param w 需要显示的控件。
- * @param fixCenterPos 是否需要自动修正控件位置，用于保持控件居中显示。
+  \brief DTitlebar::setCustomWidget is an overloaded function.
+  \brief 设置标题栏上的自定义控件.
+
+  \a w is the widget to be used as the customize widget shown in the title
+  bar.
+  \a fixCenterPos indicates whether it should automatically move the
+  customize widget to the horizontal center of the title bar or not.
+
+  \a w 需要显示的控件。
+  \a fixCenterPos 是否需要自动修正控件位置，用于保持控件居中显示。
  */
 void DTitlebar::setCustomWidget(QWidget *w, bool fixCenterPos)
 {
@@ -1045,13 +1413,12 @@ void DTitlebar::removeWidget(QWidget *w)
 }
 
 /*!
- * \~english @brief DTitlebar::setFixedHeight change the height of the title bar to
- * another value.
- * @param h is the target height.
- */
-/*!
- * \~chinese @brief 设置标题栏的高度，默认高度为 50。
- * @param h 需要设置的高度
+  \brief DTitlebar::setFixedHeight change the height of the title bar to
+  another value.
+  \brief 设置标题栏的高度，默认高度为 50。
+
+  \a h 需要设置的高度
+  \a h is the target height.
  */
 void DTitlebar::setFixedHeight(int h)
 {
@@ -1059,12 +1426,11 @@ void DTitlebar::setFixedHeight(int h)
 }
 
 /*!
- * \~english @brief DTitlebar::setBackgroundTransparent set the title background transparent
- * @param transparent is the targeting value.
- */
-/*!
- * \~chinese @brief 设置标题栏背景是否透明，当为透明时标题栏直接叠加在下层控件上。
- * @param transparent 是否透明
+  \brief DTitlebar::setBackgroundTransparent set the title background transparent
+  \brief 设置标题栏背景是否透明，当为透明时标题栏直接叠加在下层控件上.
+
+  \a transparent is the targeting value.
+  \a transparent 是否透明
  */
 void DTitlebar::setBackgroundTransparent(bool transparent)
 {
@@ -1077,13 +1443,12 @@ void DTitlebar::setBackgroundTransparent(bool transparent)
 }
 
 /*!
- * \~english @brief DTitlebar::setSeparatorVisible sets the bottom separator of the title
- * bar and the window contents to be visible or not.
- * @param visible is the targeting value.
- */
-/*!
- * \~chinese @brief 设置菜单下面的分隔线是否可见，默认是可见的。
- * @param 是否可见
+  \brief DTitlebar::setSeparatorVisible sets the bottom separator of the title
+  bar and the window contents to be visible or not.
+  \brief 设置菜单下面的分隔线是否可见，默认是可见的。
+
+  \a visible 是否可见
+  \a visible is the targeting value.
  */
 void DTitlebar::setSeparatorVisible(bool visible)
 {
@@ -1097,12 +1462,11 @@ void DTitlebar::setSeparatorVisible(bool visible)
 }
 
 /*!
- * \~english @brief DTitlebar::setTitle sets the title to be shown on the title bar.
- * @param title is the text to be used as the window title.
- */
-/*!
- * \~chinese @brief 设置标题栏文本。
- * @param 待设置内容
+  \brief DTitlebar::setTitle sets the title to be shown on the title bar.
+  \brief 设置标题栏文本。
+
+  \a title is the text to be used as the window title.
+  \a title 待设置内容
  */
 void DTitlebar::setTitle(const QString &title)
 {
@@ -1116,12 +1480,11 @@ void DTitlebar::setTitle(const QString &title)
 }
 
 /*!
- * \~english @brief DTitlebar::setIcon sets the icon to be shown on the title bar.
- * @param icon is to be used as the window icon.
- */
-/*!
- * \~chinese @brief 设置标题栏图标
- * @param 待设置的图标
+  \brief DTitlebar::setIcon sets the icon to be shown on the title bar.
+  \brief 设置标题栏图标
+
+  \a icon is to be used as the window icon.
+  \a icon 待设置的图标
  */
 void DTitlebar::setIcon(const QIcon &icon)
 {
@@ -1166,11 +1529,9 @@ void DTitlebar::setBlurBackground(bool blurBackground)
 }
 
 /*!
- * \~english @brief DTitlebar::buttonAreaWidth returns the width of the area that all the
- * window buttons occupies.
- */
-/*!
- * \~chinese @brief 按钮区域大小，用于手动定位自定义控件时使用。
+  \brief DTitlebar::buttonAreaWidth returns the width of the area that all the
+  window buttons occupies.
+  \brief 按钮区域大小，用于手动定位自定义控件时使用.
  */
 int DTitlebar::buttonAreaWidth() const
 {
@@ -1179,11 +1540,9 @@ int DTitlebar::buttonAreaWidth() const
 }
 
 /*!
- * \~english @brief DTitlebar::separatorVisible returns the visibility of the bottom
- * separator of the titlebar.
- */
-/*!
- * \~chinese @brief 分隔线是否可见。
+  \brief DTitlebar::separatorVisible returns the visibility of the bottom
+  separator of the titlebar.
+  \brief 分隔线是否可见.
  */
 bool DTitlebar::separatorVisible() const
 {
@@ -1192,11 +1551,9 @@ bool DTitlebar::separatorVisible() const
 }
 
 /*!
- * \~english @brief DTitlebar::autoHideOnFullscreen returns if titlebar show on fullscreen mode.
- * separator of the titlebar.
- */
-/*!
- * \~chinese @brief 全屏模式下标题栏是否自动隐藏
+  \brief DTitlebar::autoHideOnFullscreen returns if titlebar show on fullscreen mode.
+  separator of the titlebar.
+  \brief 全屏模式下标题栏是否自动隐藏.
  */
 bool DTitlebar::autoHideOnFullscreen() const
 {
@@ -1205,12 +1562,9 @@ bool DTitlebar::autoHideOnFullscreen() const
 }
 
 /*!
- * \~english \brief DTitlebar::setAutoHideOnFullscreen set if titlebar show when window is fullscreen state.
- * \param autohide
- */
-/*!
- * \~chinese \brief 设置全屏模式下是否需要自动隐藏标题栏
- * \param 是否自动隐藏
+  \brief DTitlebar::setAutoHideOnFullscreen set if titlebar show when window is fullscreen state.
+  \brief 设置全屏模式下是否需要自动隐藏标题栏
+  \a autohide 是否自动隐藏
  */
 void DTitlebar::setAutoHideOnFullscreen(bool autohide)
 {
@@ -1248,12 +1602,11 @@ void DTitlebar::setVisible(bool visible)
     }
 }
 
+/*!
+  \brief This function provides to set a titlebar is in parent.
+  \brief 设置为嵌入模式，而不是替换系统标题栏，用于不支持dxcb的平台.
 
-/*!
- * \~english @brief DTitlebar::setEmbedMode set a titlebar is in parent;
- */
-/*!
- * \~chinese @brief 设置为嵌入模式，而不是替换系统标题栏，用于不支持dxcb的平台
+  \a visible 为 true 时，替换系统标题栏，否则隐藏系统标题栏。
  */
 void DTitlebar::setEmbedMode(bool visible)
 {
@@ -1264,8 +1617,9 @@ void DTitlebar::setEmbedMode(bool visible)
 }
 
 /*!
- * \~chinese \brief DTitlebar::menuIsVisible
- * \~chinese \return true 菜单可见 false菜单不可见
+  \brief 菜单按钮的可视化.
+
+  \return true 菜单可见 false菜单不可见.
  */
 bool DTitlebar::menuIsVisible() const
 {
@@ -1274,8 +1628,9 @@ bool DTitlebar::menuIsVisible() const
 }
 
 /*!
- * \~chinese \brief DTitlebar::setMenuVisible 设置菜单是否可见
- * \~chinese \param visible true 菜单可见 false菜单不可见
+  \brief 设置菜单是否可见.
+
+  \a visible true 菜单可见 false菜单不可见.
  */
 void DTitlebar::setMenuVisible(bool visible)
 {
@@ -1284,8 +1639,9 @@ void DTitlebar::setMenuVisible(bool visible)
 }
 
 /*!
- * \~chinese \brief DTitlebar::menuIsDisabled
- * \~chinese \return true 菜单被禁用 false 菜单没有被禁用
+  \brief 菜单是否被禁用.
+
+  \return true 菜单被禁用 false 菜单没有被禁用。
  */
 bool DTitlebar::menuIsDisabled() const
 {
@@ -1294,8 +1650,9 @@ bool DTitlebar::menuIsDisabled() const
 }
 
 /*!
- * \~chinese \brief DTitlebar::setMenuDisabled 设置菜单是否被禁用
- * \~chinese \param disabled true 菜单被禁用 false菜单没有被禁用
+  \brief 设置菜单是否被禁用.
+
+  \a disabled true 菜单被禁用 false菜单没有被禁用。
  */
 void DTitlebar::setMenuDisabled(bool disabled)
 {
@@ -1304,8 +1661,9 @@ void DTitlebar::setMenuDisabled(bool disabled)
 }
 
 /*!
- * \~chinese \brief DTitlebar::quitMenuIsDisabled
- * \~chinese \return true 退出菜单被禁用 false退出菜单没有被禁用
+  \brief 退出菜单是否被禁用.
+
+  \return true 退出菜单被禁用 false退出菜单没有被禁用
  */
 bool DTitlebar::quitMenuIsDisabled() const
 {
@@ -1315,8 +1673,9 @@ bool DTitlebar::quitMenuIsDisabled() const
 }
 
 /*!
- * \~chinese \brief DTitlebar::setQuitMenuDisabled 设置退出菜单是否被禁用
- * \~chinese \param disabled true 退出菜单被禁用 false退出菜单没有被禁用
+  \brief 设置退出菜单是否被禁用.
+
+  \a disabled true 退出菜单被禁用 false退出菜单没有被禁用
  */
 void DTitlebar::setQuitMenuDisabled(bool disabled)
 {
@@ -1330,8 +1689,9 @@ void DTitlebar::setQuitMenuDisabled(bool disabled)
 }
 
 /*!
- * \~chinese \brief DTitlebar::setQuitMenuVisible 设置退出菜单是否被可见
- * \~chinese \param visible true 退出菜单可见 false退出菜单不可见
+  \brief 设置退出菜单是否可见.
+
+  \a visible true 退出菜单可见 false退出菜单不可见
  */
 void DTitlebar::setQuitMenuVisible(bool visible)
 {
@@ -1345,8 +1705,9 @@ void DTitlebar::setQuitMenuVisible(bool visible)
 }
 
 /*!
- * \~chinese \brief DTitlebar::switchThemeMenuIsVisible
- * \~chinese \return true 切换主题菜单可见 false切换主题菜单不可见
+  \brief 设置主题切换菜单的可视化.
+
+  \return true 切换主题菜单可见 false切换主题菜单不可见
  */
 bool DTitlebar::switchThemeMenuIsVisible() const
 {
@@ -1356,8 +1717,9 @@ bool DTitlebar::switchThemeMenuIsVisible() const
 }
 
 /*!
- * \~chinese \brief DTitlebar::setSwitchThemeMenuVisible 设置切换主题菜单是否可见
- * \~chinese \param visible true 切换主题菜单可见 false切换主题菜单不可见
+  \brief 设置切换主题菜单是否可见.
+
+  \a visible true 切换主题菜单可见 false 切换主题菜单不可见。
  */
 void DTitlebar::setSwitchThemeMenuVisible(bool visible)
 {
@@ -1376,12 +1738,10 @@ void DTitlebar::setSwitchThemeMenuVisible(bool visible)
 }
 
 /*!
- * \~english \brief DTitlebar::setDisableFlags will disable button match flags.
- * \param flags
- */
-/*!
- * \~chinese \brief 设置需要被禁用的按钮，仅仅是在界面上禁用按钮，还是可以通过事件等机制来调用对应接口。
- * \param flags 需要被禁用的按钮标志位
+  \brief This function provides to disable the button match flags.
+  \brief 设置需要被禁用的按钮，仅仅是在界面上禁用按钮，还是可以通过事件等机制来调用对应接口.
+
+  \a flags 需要被禁用的按钮标志位
  */
 void DTitlebar::setDisableFlags(Qt::WindowFlags flags)
 {
@@ -1391,10 +1751,10 @@ void DTitlebar::setDisableFlags(Qt::WindowFlags flags)
 }
 
 /*!
- * \~english \brief DTitlebar::disableFlags return which button is disabled.
- */
-/*!
- * \~chinese \brief 当前被禁用的按钮标志位。
+  \brief Return which button is disabled.
+  \brief 当前被禁用的按钮标志位.
+
+  \return 被禁用的窗口标志。
  */
 Qt::WindowFlags DTitlebar::disableFlags() const
 {
@@ -1402,6 +1762,18 @@ Qt::WindowFlags DTitlebar::disableFlags() const
     return d->disableFlags;
 }
 
+void DTitlebar::setSplitScreenEnabled(bool enabled)
+{
+    D_D(DTitlebar);
+    d->splitScreenWidgetEnable = enabled;
+}
+
+bool DTitlebar::splitScreenIsEnabled() const
+{
+    D_DC(DTitlebar);
+    return d->splitScreenWidgetEnable;
+}
+
 QSize DTitlebar::sizeHint() const
 {
     D_DC(DTitlebar);
