@@ -300,7 +300,13 @@ void Content::updateSettings(const QByteArray &translateContext, QPointer<DTK_CO
                     }
 
                     if (widget.first) {
-                        hLay->addWidget(widget.first, 2);
+                        QWidget *container = new QWidget;
+                        QHBoxLayout *hLayout = new QHBoxLayout(container);
+                        hLayout->setSpacing(0);
+                        hLayout->setMargin(0);
+                        hLayout->addWidget(widget.first);
+                        hLayout->addStretch(1);
+                        hLay->addWidget(container, 2);
                     }
                     if (widget.second) {
                         hLay->addWidget(widget.second, 3);
